# aliases: sbc


# parts
```bash
@sbc \
	parts \
	adjust \
	[dryrun,~grid] \
	[--verbose 1]
 . adjust part images.
@sbc \
	parts \
	cd
 . cd to part images folder.
@sbc \
	parts \
	edit
 . edit parts db.
@sbc \
	parts \
	open
 . open part images folder.
```

# rpi
```bash
@sbc \
	rpi \
	fake_display \
	[dryrun]
 . fake the display on an rpi.
```
